==> jc-1.4.0.tar.gz: gnu/regexp/CharIndexedCharArray.h <==
// class gnu.regexp.CharIndexedCharArray

// class file dependencies
// @dep_class 8405b2f8dd2c654a gnu_regexp_CharIndexedCharArray
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_CharIndexedCharArray_H_
#define _JC_gnu_regexp_CharIndexedCharArray_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_regexp_CharIndexedCharArray$sub_refs	_jc_gnu_regexp_CharIndexedCharArray$sub_refs;
typedef struct _jc_gnu_regexp_CharIndexedCharArray$sub_nonrefs	_jc_gnu_regexp_CharIndexedCharArray$sub_nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedCharArray$refs	_jc_gnu_regexp_CharIndexedCharArray$refs;
typedef struct _jc_gnu_regexp_CharIndexedCharArray$nonrefs	_jc_gnu_regexp_CharIndexedCharArray$nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedCharArray$object	_jc_gnu_regexp_CharIndexedCharArray$object;

typedef const struct _jc_gnu_regexp_CharIndexedCharArray$vmethods	_jc_gnu_regexp_CharIndexedCharArray$vmethods;
typedef const struct _jc_gnu_regexp_CharIndexedCharArray$vtable	_jc_gnu_regexp_CharIndexedCharArray$vtable;
typedef const struct _jc_gnu_regexp_CharIndexedCharArray$vtype	_jc_gnu_regexp_CharIndexedCharArray$vtype;

// Constructors
extern void _jc_gnu_regexp_CharIndexedCharArray$method$_init$d051b5884a87b8dc(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *, struct _jc_char_array *, jint);

// Virtual methods
extern jchar _jc_gnu_regexp_CharIndexedCharArray$method$charAt$bb9507ba35769182(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *, jint);
extern jboolean _jc_gnu_regexp_CharIndexedCharArray$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *);
extern jboolean _jc_gnu_regexp_CharIndexedCharArray$method$move$bcf9c6b955daae71(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *, jint);

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_CharIndexedCharArray$method_info$charAt$bb9507ba35769182;
extern _jc_method _jc_gnu_regexp_CharIndexedCharArray$method_info$isValid$835d853ce0a23705;
extern _jc_method _jc_gnu_regexp_CharIndexedCharArray$method_info$move$bcf9c6b955daae71;

// Virtual methods structure
struct _jc_gnu_regexp_CharIndexedCharArray$vmethods {
	jchar	(*charAt$bb9507ba35769182)(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *, jint);
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *);
	jboolean	(*move$bcf9c6b955daae71)(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *, jint);
};

// Vtable
struct _jc_gnu_regexp_CharIndexedCharArray$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_CharIndexedCharArray$vmethods	gnu_regexp_CharIndexedCharArray;
};

// Vtype
struct _jc_gnu_regexp_CharIndexedCharArray$vtype {
	_jc_type			type;
	_jc_gnu_regexp_CharIndexedCharArray$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedCharArray$sub_refs {
	_jc_char_array	*s;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedCharArray$refs {
    _jc_gnu_regexp_CharIndexedCharArray$sub_refs	gnu_regexp_CharIndexedCharArray;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedCharArray$sub_nonrefs {
	jint	anchor;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedCharArray$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_CharIndexedCharArray$sub_nonrefs	gnu_regexp_CharIndexedCharArray;
};

// Object instance structure
struct _jc_gnu_regexp_CharIndexedCharArray$object {
	_jc_gnu_regexp_CharIndexedCharArray$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_CharIndexedCharArray$vtype	*vtype;
	_jc_gnu_regexp_CharIndexedCharArray$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_CharIndexedCharArray$vtype _jc_gnu_regexp_CharIndexedCharArray$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_CharIndexedCharArray, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_CharIndexedCharArray$class_object;

#endif	/* _JC_gnu_regexp_CharIndexedCharArray_H_ */

==> jc-1.4.6.tar.gz: gnu/regexp/CharIndexedCharArray.h <==
// class gnu.regexp.CharIndexedCharArray

// class file dependencies
// @dep_class 8405b2f8dd2c654a gnu_regexp_CharIndexedCharArray
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_gnu_regexp_CharIndexedCharArray_H_
#define _JC_gnu_regexp_CharIndexedCharArray_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_regexp_CharIndexedCharArray$sub_refs	_jc_gnu_regexp_CharIndexedCharArray$sub_refs;
typedef struct _jc_gnu_regexp_CharIndexedCharArray$sub_nonrefs	_jc_gnu_regexp_CharIndexedCharArray$sub_nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedCharArray$refs	_jc_gnu_regexp_CharIndexedCharArray$refs;
typedef struct _jc_gnu_regexp_CharIndexedCharArray$nonrefs	_jc_gnu_regexp_CharIndexedCharArray$nonrefs;
typedef struct _jc_gnu_regexp_CharIndexedCharArray$object	_jc_gnu_regexp_CharIndexedCharArray$object;

typedef const struct _jc_gnu_regexp_CharIndexedCharArray$vmethods	_jc_gnu_regexp_CharIndexedCharArray$vmethods;
typedef const struct _jc_gnu_regexp_CharIndexedCharArray$vtable	_jc_gnu_regexp_CharIndexedCharArray$vtable;
typedef const struct _jc_gnu_regexp_CharIndexedCharArray$vtype	_jc_gnu_regexp_CharIndexedCharArray$vtype;

// Constructors
extern void _jc_gnu_regexp_CharIndexedCharArray$method$_init$d051b5884a87b8dc(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *, struct _jc_char_array *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jchar _jc_gnu_regexp_CharIndexedCharArray$method$charAt$bb9507ba35769182(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *, jint) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_CharIndexedCharArray$method$isValid$835d853ce0a23705(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *) _JC_JCNI_ATTR;
extern jboolean _jc_gnu_regexp_CharIndexedCharArray$method$move$bcf9c6b955daae71(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_regexp_CharIndexedCharArray$method_info$charAt$bb9507ba35769182;
extern _jc_method _jc_gnu_regexp_CharIndexedCharArray$method_info$isValid$835d853ce0a23705;
extern _jc_method _jc_gnu_regexp_CharIndexedCharArray$method_info$move$bcf9c6b955daae71;

// Virtual methods structure
struct _jc_gnu_regexp_CharIndexedCharArray$vmethods {
	jchar	(*charAt$bb9507ba35769182)(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *, jint) _JC_JCNI_ATTR;
	jboolean	(*isValid$835d853ce0a23705)(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *) _JC_JCNI_ATTR;
	jboolean	(*move$bcf9c6b955daae71)(_jc_env *, struct _jc_gnu_regexp_CharIndexedCharArray$object *, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_regexp_CharIndexedCharArray$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_regexp_CharIndexedCharArray$vmethods	gnu_regexp_CharIndexedCharArray;
};

// Vtype
struct _jc_gnu_regexp_CharIndexedCharArray$vtype {
	_jc_type			type;
	_jc_gnu_regexp_CharIndexedCharArray$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedCharArray$sub_refs {
	_jc_char_array	*s;
};

// Reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedCharArray$refs {
    _jc_gnu_regexp_CharIndexedCharArray$sub_refs	gnu_regexp_CharIndexedCharArray;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_regexp_CharIndexedCharArray$sub_nonrefs {
	jint	anchor;
};

// Non-reference instance fields (object)
struct _jc_gnu_regexp_CharIndexedCharArray$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_regexp_CharIndexedCharArray$sub_nonrefs	gnu_regexp_CharIndexedCharArray;
};

// Object instance structure
struct _jc_gnu_regexp_CharIndexedCharArray$object {
	_jc_gnu_regexp_CharIndexedCharArray$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_regexp_CharIndexedCharArray$vtype	*vtype;
	_jc_gnu_regexp_CharIndexedCharArray$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_regexp_CharIndexedCharArray$vtype _jc_gnu_regexp_CharIndexedCharArray$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_regexp_CharIndexedCharArray, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_regexp_CharIndexedCharArray$class_object;

#endif	/* _JC_gnu_regexp_CharIndexedCharArray_H_ */
